@@ -1,3 +1,4 @@
+import hashlib
 from six import ensure_text
 import shutil
 import logging
@@ -550,6 +551,20 @@ class Manifest(object):
         if self.path.exists():
             shutil.rmtree(self.path, ignore_errors=True)
 
+    def checksum(self):
+        """
+        Computes the checksum of the module itself.
+        This can later be used to check if the module has changed
+        and force an update of the module as the version that
+        is installed doesn't match the one on the filesystem.
+        """
+        check = hashlib.sha1()
+
+        for file in self.files():
+            check.update(file.open('rb').read())
+
+        return check
+
     def files(self):
         """
         Yields all file located in the module's folder.
@@ -559,12 +574,16 @@ class Manifest(object):
         considered as "sources". It will also yield files located in
         the static folder.
         """
-        for file in self.path.glob('**/*'):
-            if file.is_dir():
-                continue
-            if file.name.endswith('.pyc'):
-                continue
+        all_files = [
+            file
+            for file in self.path.glob('**/*')
+            if not file.is_dir()
+            if not file.name.endswith('.pyc')
+        ]
 
+        all_files.sort()
+
+        for file in all_files:
             yield file
 
     def package(self):
