@@ -2,6 +2,33 @@ import pytest
 from pathlib import Path
 from odoo_tools.api.objects import CompanySpec, Manifest
 
+fake_files = {
+    "__init__.py": """
+from . import models
+from . import controllers
+""",
+    "models/__init__.py": """
+from . import sale_obj
+""",
+    "models/sale_obj": """
+from odoo import models
+
+class MyObj(models.Model):
+    _name = "my.obj"
+""",
+    "controllers/__init__.py": """
+from . import main
+""",
+    "controllers/main.py": """
+from odoo.http import Controller
+
+class MyController(Controller):
+    @http.route()
+    def whoa():
+        return ""
+"""
+    }
+
 
 def test_company_spec():
     company = CompanySpec(country_code='CA')
@@ -111,3 +138,40 @@ def test_invalid_manifest(tmp_path):
 
     with pytest.raises(SyntaxError):
         manifest = Manifest.from_path(manifest.path)
+
+
+def test_manifest_checksum(tmp_path):
+    module_path = tmp_path / 'sup'
+
+    manifest = Manifest(tmp_path / 'sup')
+
+    manifest.set_attribute(
+        ['external_dependencies', 'python'],
+        ['web', 'base', 'fun']
+    )
+
+    manifest.save()
+
+    main_controller = module_path / 'controllers/main.py'
+    manifest_file = module_path / '__manifest__.py'
+
+    # Add file to generate valid module
+    for filename, data in fake_files.items():
+        file_path = module_path / filename
+        file_path.parent.mkdir(exist_ok=True, parents=True)
+        with file_path.open('w') as fout:
+            fout.write(data)
+    checksum = manifest.checksum()
+    assert checksum.hexdigest() == "01f34218933d0cc173a1cac18ca6c96779901de9"
+
+    # Ensure that sub file modified changes checksum
+    with main_controller.open('w') as fout:
+        fout.write("import odoo\n")
+    checksum = manifest.checksum()
+    assert checksum.hexdigest() == "006236cde58f9110ccfc1aea264bee2da8c3fc1f"
+
+    # Check that manifest is part of the file
+    with manifest_file.open('w') as fout:
+        fout.write('{}')
+    checksum = manifest.checksum()
+    assert checksum.hexdigest() == "f7daa17811c84315adf726ad7e6a026943b48a22"
